library(margins)
library(pROC)

# Test treatment effect

database_full <- database_full %>%
  filter(!is.na(Treatment_new)) %>%
  mutate(Dummy_Video_1 = case_when(Treatment_new == 1 ~ 1, TRUE ~ 0),
         Dummy_Video_2 = case_when(Treatment_new == 5 ~ 1, TRUE ~ 0),
         Dummy_no_info = case_when(Treatment_new == 3 ~ 1, TRUE~0),
         Dummy_Info_nv1 = case_when(Treatment_new == 2 ~1, TRUE~0),
         Dummy_Info_nv2 = case_when(Treatment_new == 4 ~1 , TRUE~0)) %>% 
  mutate(Engagement_ugs = groupTime1731 + groupTime1726 + groupTime1769 + groupTime1727 + groupTime1770 + groupTime1771 + groupTime1768 +
           groupTime1738)




data <- database_full %>%
  group_by(id) %>%
  slice(1) %>%
  ungroup()
data <- data %>% 
  mutate(Choice_Treat = ifelse( Dummy_Video_2 == 1 | Dummy_Info_nv2 == 1, 1, 
                               ifelse(Dummy_no_info==1 ,0,NA))) 



table(data$Choice_Treat)  


      
logit_choice_treat<-glm(Choice_Treat ~  as.factor(Gender)+Z_Mean_NR+Age_mean + QFIncome +
                          as.factor(Education), data, family=binomial)
summary(logit_choice_treat)


logit_choice_treat_uni<-glm(Choice_Treat ~  as.factor(Gender)+Z_Mean_NR+Age_mean + QFIncome +
                          Uni_degree + Kids_Dummy + Engagement_ugs + UGS_visits, data, family=binomial)
summary(logit_choice_treat_uni)


logit_sig <- glm(Choice_Treat ~  Z_Mean_NR + Age_mean + QFIncome + UGS_visits, data, family=binomial)

# Calculate marginal effects
marginal_effects <- margins(logit_choice_treat_uni)

# Display the marginal effects
summary(marginal_effects)               


cut_off <- 0.45


# Make predictions
data$probabilities <- logit_sig %>% predict(data, type = "response")
data$predicted.classes <- ifelse(data$probabilities  >= cut_off, 1, 0)
# Model accuracy
mean(data$predicted.classes == data$Choice_Treat, na.rm = T)

table(data$predicted.classes ,data$Choice_Treat)

calculate_metrics <- function(confusion_matrix) {
  # Extract values from the confusion matrix
  TN <- confusion_matrix[1, 1]
  FP <- confusion_matrix[2, 1]
  FN <- confusion_matrix[1, 2]
  TP <- confusion_matrix[2, 2]
  
  # Calculate sensitivity
  sensitivity <- round(TP / (TP + FN), 2)
  
  # Calculate specificity
  specificity <- round(TN / (TN + FP), 2)
  
  # Return the results as a list
  return(list(sensitivity = sensitivity, specificity = specificity))
}

# Calculate metrics
metrics <- calculate_metrics(table(data$predicted.classes ,data$Choice_Treat))

# Print results
print(paste("Sensitivity:", metrics$sensitivity))
print(paste("Specificity:", metrics$specificity))
roc_obj <- roc(data$Choice_Treat, data$probabilities)
plot(roc_obj, main = "ROC Curve", col = "blue", lwd = 2)
auc_value <- auc(roc_obj)
best_coords <- coords(roc_obj, "best", best.method="youden")


cut_off <- best_coords$threshold

